@@ -86,7 +86,7 @@
 #define KIDLETIME_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIDLETIME_NO_DEPRECATED
-#  define KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KIDLETIME_NO_DEPRECATED_WARNINGS
 #  define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIDLETIME_DEPRECATED_WARNINGS_SINCE KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -118,5 +118,12 @@
 #define KIDLETIME_DEPRECATED_VERSION_5(minor, text)      KIDLETIME_DEPRECATED_VERSION_5_##minor(text)
 #define KIDLETIME_DEPRECATED_VERSION(major, minor, text) KIDLETIME_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KIDLETIME_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIDLETIME_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KIDLETIME_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KIDLETIME_DEPRECATED_VERSION(major, minor, text)
+#  define KIDLETIME_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIDLETIME_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KIDLETIME_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KIDLETIME_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KIDLETIME_EXPORT_H */
